@@ -44,37 +44,6 @@ static void fr_command_cfile_finalize    (GObject             *object);
 static FRCommandClass *parent_class = NULL;
 
 
-static char *
-eat_spaces (char *line)
-{
-	while ((*line == ' ') && (*line != 0))
-		line++;
-	return line;
-}
-
-
-static char **
-split_line (char *line, 
-	    int   n_fields)
-{
-	char **fields;
-	char  *scan, *field_end;
-	int    i;
-
-	fields = g_new0 (char *, n_fields + 1);
-	fields[n_fields] = NULL;
-
-	scan = eat_spaces (line);
-	for (i = 0; i < n_fields; i++) {
-		field_end = strchr (scan, ' ');
-		fields[i] = g_strndup (scan, field_end - scan);
-		scan = eat_spaces (field_end);
-	}
-
-	return fields;
-}
-
-
 static void
 list__process_line (char     *line, 
 		    gpointer  data)
@@ -90,6 +59,9 @@ list__process_line (char     *line,
 	fdata->size = atol (fields[1]);
 	g_strfreev (fields);
 
+	if (fdata->size == -1)
+		fdata->size = get_file_size (comm->filename);
+
 	filename = remove_extension_from_path (comm->filename);
 	fdata->full_path = g_strconcat ("/", 
 					file_name_from_path (filename),
@@ -191,18 +163,6 @@ fr_command_cfile_delete (FRCommand *comm,
 }
 
 
-static gchar *
-get_temp_dir_name ()
-{
-	static int count = 0;
-	return g_strdup_printf ("%s%s.%d.%d",
-				g_get_tmp_dir (),
-				"/file-roller-cfile",
-				getpid (),
-				count++);
-}
-
-
 static void
 fr_command_cfile_extract (FRCommand  *comm,
 			  GList      *file_list,
@@ -219,7 +179,7 @@ fr_command_cfile_extract (FRCommand  *comm,
 	char           *temp_file;
 	char           *uncompr_file;
 
-	temp_dir = get_temp_dir_name ();
+	temp_dir = get_temp_work_dir_name ();
 	e_temp_dir = shell_escape (temp_dir);
 
 	/* create a temp dir. */
