@@ -1,13 +1,6 @@
 /* GdkPixbuf RGBA C-Source image dump */
 
-#ifdef __SUNPRO_C
-#pragma align 4 (add_pixbuf)
-#endif
-#ifdef __GNUC__
-static const guint8 add_pixbuf[] __attribute__ ((__aligned__ (4))) = 
-#else
 static const guint8 add_pixbuf[] = 
-#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
@@ -120,14 +113,7 @@ static const guint8 add_pixbuf[] =
 
 /* GdkPixbuf RGBA C-Source image dump */
 
-#ifdef __SUNPRO_C
-#pragma align 4 (extract_pixbuf)
-#endif
-#ifdef __GNUC__
-static const guint8 extract_pixbuf[] __attribute__ ((__aligned__ (4))) = 
-#else
 static const guint8 extract_pixbuf[] = 
-#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
@@ -239,14 +225,7 @@ static const guint8 extract_pixbuf[] =
 
 /* GdkPixbuf RGBA C-Source image dump */
 
-#ifdef __SUNPRO_C
-#pragma align 4 (view_pixbuf)
-#endif
-#ifdef __GNUC__
-static const guint8 view_pixbuf[] __attribute__ ((__aligned__ (4))) = 
-#else
 static const guint8 view_pixbuf[] = 
-#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
@@ -370,14 +349,7 @@ static const guint8 view_pixbuf[] =
 
 /* GdkPixbuf RGBA C-Source image dump */
 
-#ifdef __SUNPRO_C
-#pragma align 4 (folder_rgba)
-#endif
-#ifdef __GNUC__
-static const guint8 folder_rgba[] __attribute__ ((__aligned__ (4))) = 
-#else
 static const guint8 folder_rgba[] = 
-#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
@@ -477,14 +449,7 @@ static const guint8 folder_rgba[] =
 
 /* GdkPixbuf RGBA C-Source image dump */
 
-#ifdef __SUNPRO_C
-#pragma align 4 (file_rgba)
-#endif
-#ifdef __GNUC__
-static const guint8 file_rgba[] __attribute__ ((__aligned__ (4))) = 
-#else
 static const guint8 file_rgba[] = 
-#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
